##  Initiative Fact Sheet Subtypes
The following four different fact sheet subtypes are available to model different types of initiatives in SAP LeanIX:
  * Idea: Ideas are changes under consideration, not formally planned out yet (e.g., in a project or program).
Example: Scenario A - ERP Greenfield Implementation ('Scenario' as a differentiator to show this is one of several ideas).
  * Program: Programs are a group of related projects, epics, or other sub-programs to achieve strategic objectives, ideally managed in synchronization with a project management tool.
Example: Cloud Transformation Program
  * Project: Projects are ideally managed and synchronized with a project management tool. They can be separate or a child of (a) program(s) in the context of large/complex transformations.
Example: Wave 1 - Rehost Project
  * Epic: Epics are the standard way to execute changes in a modern product-oriented organization, ideally managed in synchronization with an agile planning tool like Jira.
Example: Messaging integration for Customer Support


**Note**
For a step-by-step guide to create the fact sheet subtype, see [Add Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/configure-workspace-meta-model-v4?locale=en-US&state=PRODUCTION&version=CLOUD#loio27595ce97a4410149c60a90e0f529a04__add_fact_sheet_subtypes_to_several_fact_sheet_types).
Initiative examples:
  * Business initiative: Streamline supply chain processes to improve efficiency
  * IT initiative: Move to SAP S/4HANA Supply Chain on public cloud
